
dialogId("dlg-x-poster1", "font_poster", "Greetings from the rubbish heap to our beloved boss.")
dialogStr("Viele Grüsse vom Müllhaufen an unseren geliebten Chef.")


dialogId("dlg-x-poster2", "font_poster", "Yours sincerely")
dialogStr("Mit freundlichen Grüssen")


dialogId("dlg-x-poster4", "font_poster", "PS: It's great to be here. We irradiate ourselves and swim in the sea a lot. We have many new friends.")
dialogStr("PS: Hier ist es grossartig. Wir strahlen übers ganze Gesicht und schwimmen oft im Meer. Wir haben viele neue Freunde.")

